@@ -16,3 +16,7 @@ class RateLimited(APIError):
     def __init__(self, message, retry_after=0):
         self.retry_after = retry_after
         super(RateLimited, self).__init__(message, 429)
+
+
+class InvalidGitRepository(Exception):
+    pass
